==> estateplat-common-1.2.4-20201113.014416-502-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/KttZdjbxxBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.KttZdjbxx;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


public class KttZdjbxxBdc extends KttZdjbxx {
    private String dfytdm;
    private String dfytmc;
    private String dfdjdm;
    private String dfdjmc;
    private String dfqllxdm;
    private String dfqllxmc;
    private String dfqlxzdm;
    private String dfqlxzmc;
    private String dfqlsdfsdm;
    private String dfqlsdfsmc;
    private String dfztdm;
    private String dfztmc;
    @XmlAttribute(
            name = "DFYTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfytdm() {
        return dfytdm;
    }

    public void setDfytdm(String dfytdm) {
        this.dfytdm = dfytdm;
    }
    @XmlAttribute(
            name = "DFYTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfytmc() {
        return dfytmc;
    }

    public void setDfytmc(String dfytmc) {
        this.dfytmc = dfytmc;
    }
    @XmlAttribute(
            name = "DFDJDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfdjdm() {
        return dfdjdm;
    }

    public void setDfdjdm(String dfdjdm) {
        this.dfdjdm = dfdjdm;
    }
    @XmlAttribute(
            name = "DFDJMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfdjmc() {
        return dfdjmc;
    }

    public void setDfdjmc(String dfdjmc) {
        this.dfdjmc = dfdjmc;
    }
    @XmlAttribute(
            name = "DFQLLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfqllxdm() {
        return dfqllxdm;
    }

    public void setDfqllxdm(String dfqllxdm) {
        this.dfqllxdm = dfqllxdm;
    }
    @XmlAttribute(
            name = "DFQLLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfqllxmc() {
        return dfqllxmc;
    }

    public void setDfqllxmc(String dfqllxmc) {
        this.dfqllxmc = dfqllxmc;
    }
    @XmlAttribute(
            name = "DFQLXZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfqlxzdm() {
        return dfqlxzdm;
    }

    public void setDfqlxzdm(String dfqlxzdm) {
        this.dfqlxzdm = dfqlxzdm;
    }
    @XmlAttribute(
            name = "DFQLXZMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfqlxzmc() {
        return dfqlxzmc;
    }

    public void setDfqlxzmc(String dfqlxzmc) {
        this.dfqlxzmc = dfqlxzmc;
    }
    @XmlAttribute(
            name = "DFQLSDFSDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfqlsdfsdm() {
        return dfqlsdfsdm;
    }

    public void setDfqlsdfsdm(String dfqlsdfsdm) {
        this.dfqlsdfsdm = dfqlsdfsdm;
    }
    @XmlAttribute(
            name = "DFQLSDFSMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfqlsdfsmc() {
        return dfqlsdfsmc;
    }

    public void setDfqlsdfsmc(String dfqlsdfsmc) {
        this.dfqlsdfsmc = dfqlsdfsmc;
    }
    @XmlAttribute(
            name = "DFZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfztdm() {
        return dfztdm;
    }

    public void setDfztdm(String dfztdm) {
        this.dfztdm = dfztdm;
    }
    @XmlAttribute(
            name = "DFZTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfztmc() {
        return dfztmc;
    }

    public void setDfztmc(String dfztmc) {
        this.dfztmc = dfztmc;
    }
}

==> estateplat-common-1.2.4-20201117.033547-511-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/KttZdjbxxBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.KttZdjbxx;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


public class KttZdjbxxBdc extends KttZdjbxx {
    private String dfytdm;
    private String dfytmc;
    private String dfdjdm;
    private String dfdjmc;
    private String dfqllxdm;
    private String dfqllxmc;
    private String dfqlxzdm;
    private String dfqlxzmc;
    private String dfqlsdfsdm;
    private String dfqlsdfsmc;
    private String dfztdm;
    private String dfztmc;
    @XmlAttribute(
            name = "DFYTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfytdm() {
        return dfytdm;
    }

    public void setDfytdm(String dfytdm) {
        this.dfytdm = dfytdm;
    }
    @XmlAttribute(
            name = "DFYTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfytmc() {
        return dfytmc;
    }

    public void setDfytmc(String dfytmc) {
        this.dfytmc = dfytmc;
    }
    @XmlAttribute(
            name = "DFDJDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjdm() {
        return dfdjdm;
    }

    public void setDfdjdm(String dfdjdm) {
        this.dfdjdm = dfdjdm;
    }
    @XmlAttribute(
            name = "DFDJMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjmc() {
        return dfdjmc;
    }

    public void setDfdjmc(String dfdjmc) {
        this.dfdjmc = dfdjmc;
    }
    @XmlAttribute(
            name = "DFQLLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqllxdm() {
        return dfqllxdm;
    }

    public void setDfqllxdm(String dfqllxdm) {
        this.dfqllxdm = dfqllxdm;
    }
    @XmlAttribute(
            name = "DFQLLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqllxmc() {
        return dfqllxmc;
    }

    public void setDfqllxmc(String dfqllxmc) {
        this.dfqllxmc = dfqllxmc;
    }
    @XmlAttribute(
            name = "DFQLXZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqlxzdm() {
        return dfqlxzdm;
    }

    public void setDfqlxzdm(String dfqlxzdm) {
        this.dfqlxzdm = dfqlxzdm;
    }
    @XmlAttribute(
            name = "DFQLXZMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqlxzmc() {
        return dfqlxzmc;
    }

    public void setDfqlxzmc(String dfqlxzmc) {
        this.dfqlxzmc = dfqlxzmc;
    }
    @XmlAttribute(
            name = "DFQLSDFSDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqlsdfsdm() {
        return dfqlsdfsdm;
    }

    public void setDfqlsdfsdm(String dfqlsdfsdm) {
        this.dfqlsdfsdm = dfqlsdfsdm;
    }
    @XmlAttribute(
            name = "DFQLSDFSMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqlsdfsmc() {
        return dfqlsdfsmc;
    }

    public void setDfqlsdfsmc(String dfqlsdfsmc) {
        this.dfqlsdfsmc = dfqlsdfsmc;
    }
    @XmlAttribute(
            name = "DFZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfztdm() {
        return dfztdm;
    }

    public void setDfztdm(String dfztdm) {
        this.dfztdm = dfztdm;
    }
    @XmlAttribute(
            name = "DFZTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfztmc() {
        return dfztmc;
    }

    public void setDfztmc(String dfztmc) {
        this.dfztmc = dfztmc;
    }
}
